# Changelog

## 0.8.0 (2025-11-26)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/cjavdev/spotted-py/compare/v0.7.0...v0.8.0)

### Features

* **api:** manual updates ([b652327](https://github.com/cjavdev/spotted-py/commit/b652327891d1d5d7ee2e897c980dfd0fdf6f5337))
* **api:** manual updates ([2cac07d](https://github.com/cjavdev/spotted-py/commit/2cac07da2470d5ff47fec8b0ab75785653f9197d))


### Chores

* add Python 3.14 classifier and testing ([0efd78a](https://github.com/cjavdev/spotted-py/commit/0efd78a9e9ce1f1d48942d50b1da024adfeea782))

## 0.7.0 (2025-11-20)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/cjavdev/spotted-py/compare/v0.6.0...v0.7.0)

### Features

* **api:** manual updates ([6eb6bf7](https://github.com/cjavdev/spotted-py/commit/6eb6bf78cfcc64fb4de44cd1fd2662ee2fb24a81))

## 0.6.0 (2025-11-20)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/cjavdev/spotted-py/compare/v0.5.0...v0.6.0)

### Features

* **api:** manual updates ([93d44d4](https://github.com/cjavdev/spotted-py/commit/93d44d4c25f09433ba82b5dc6a42eabd979ada4b))

## 0.5.0 (2025-11-20)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/cjavdev/spotted-py/compare/v0.4.0...v0.5.0)

### Features

* **api:** manual updates ([f0ac812](https://github.com/cjavdev/spotted-py/commit/f0ac8127edd6617494dbe1cfeda02dfb1625a489))
* **api:** rename public to published for java ([114661e](https://github.com/cjavdev/spotted-py/commit/114661e6517185d0a30a1117d65537350f47dbdd))

## 0.4.0 (2025-11-20)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/cjavdev/spotted-py/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates ([6e6dd96](https://github.com/cjavdev/spotted-py/commit/6e6dd969a1167eeb833e8e92bfd9593640edaea2))

## 0.3.0 (2025-11-20)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/cjavdev/spotted-py/compare/v0.2.0...v0.3.0)

### Features

* **api:** manual updates ([7fcfe44](https://github.com/cjavdev/spotted-py/commit/7fcfe449b00fc37d9e898c7e1966d31d8951909e))

## 0.2.0 (2025-11-19)

Full Changelog: [v0.1.1...v0.2.0](https://github.com/cjavdev/spotted-py/compare/v0.1.1...v0.2.0)

### Features

* **api:** manual updates ([e143794](https://github.com/cjavdev/spotted-py/commit/e143794da0c71c2e387720a971365a76ebe18b0d))

## 0.1.1 (2025-11-19)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/cjavdev/spotted-py/compare/v0.1.0...v0.1.1)

## 0.1.0 (2025-11-18)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/cjavdev/spotted-py/compare/v0.0.1...v0.1.0)

### Features

* **api:** add mode constants ([fe70b6e](https://github.com/cjavdev/spotted-py/commit/fe70b6e677b8f98b322ede5472f8d4b1b13fb7bb))
* **api:** Adds custom helper for datetime conversion ([f0af8af](https://github.com/cjavdev/spotted-py/commit/f0af8afa4464c570a6f9d5e9399e85b981fca073))
* **api:** manual updates ([5c1e5ab](https://github.com/cjavdev/spotted-py/commit/5c1e5ab2a28773a2ead1a2fdcd317d6d9b09e906))
* **api:** manual updates ([dc95eba](https://github.com/cjavdev/spotted-py/commit/dc95ebac61d03d6efc285deed1bf9f33aa2589fe))
* **api:** manual updates ([f41e552](https://github.com/cjavdev/spotted-py/commit/f41e552da24806e9b515666fb0cbc3210f5d1a29))
* **api:** manual updates ([a514df1](https://github.com/cjavdev/spotted-py/commit/a514df15645be8ff106a7e20878e7c2d86fbdd1e))
* **api:** manual updates ([93de3c8](https://github.com/cjavdev/spotted-py/commit/93de3c88aa02793b460728c85dd3799effb9fecd))
* **api:** manual updates ([8c0849b](https://github.com/cjavdev/spotted-py/commit/8c0849b67194ae3df5f5d7cc447990ad26390ed8))
* **api:** manual updates ([8629913](https://github.com/cjavdev/spotted-py/commit/8629913995e32220a2c4071dfb0ba317b2fb4c5f))
* **api:** manual updates ([269750a](https://github.com/cjavdev/spotted-py/commit/269750ad5aa66cea4771475fb52dfe3697d04664))
* **api:** manual updates ([bd0d036](https://github.com/cjavdev/spotted-py/commit/bd0d036467ee7e14f10b60f47fa0566116f2a4d3))
* **api:** manual updates ([756bf99](https://github.com/cjavdev/spotted-py/commit/756bf99c5d078381f75483e2c3178b7848a7ff30))
* **api:** manual updates ([33cb4d6](https://github.com/cjavdev/spotted-py/commit/33cb4d667533e3fb999c40e524e30f47e0667f33))
* **api:** manual updates ([5bbf5b7](https://github.com/cjavdev/spotted-py/commit/5bbf5b73cca26561170cf225b6514fdcd1de6e0d))
* **api:** manual updates ([97307b9](https://github.com/cjavdev/spotted-py/commit/97307b9a3cf8f9ad3026d9e8ceba887caf776c3a))
* **api:** manual updates ([bbdbaaf](https://github.com/cjavdev/spotted-py/commit/bbdbaafeb0c9bb55c9b5247ed4dd6c787911adcd))
* **api:** manual updates ([1769b1d](https://github.com/cjavdev/spotted-py/commit/1769b1d49bf18b106af7138217cfb236d29f1f59))
* **api:** manual updates ([4a52d9c](https://github.com/cjavdev/spotted-py/commit/4a52d9c18970a62a6baa32ab98850ef6db59b4d2))


### Bug Fixes

* **client:** close streams without requiring full consumption ([2201b8f](https://github.com/cjavdev/spotted-py/commit/2201b8f6ad6095a3d536326bb632b84611910ec2))
* compat with Python 3.14 ([fa79197](https://github.com/cjavdev/spotted-py/commit/fa79197ad033922d3cbf1cb25a9906fdc09c8c75))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([4775114](https://github.com/cjavdev/spotted-py/commit/477511475b7a83e098fd0b9849d69724b579a26d))


### Chores

* configure new SDK language ([d2c56e0](https://github.com/cjavdev/spotted-py/commit/d2c56e00920aab81e56b19a8f4d2463047a7c0e5))
* **internal/tests:** avoid race condition with implicit client cleanup ([f33ff4f](https://github.com/cjavdev/spotted-py/commit/f33ff4f7c2414a6fcdc4378fafa5b830ce1bfc82))
* **internal:** grammar fix (it's -&gt; its) ([d6b679c](https://github.com/cjavdev/spotted-py/commit/d6b679c4c2895082af59daa3e565db90ac895bf9))
* **package:** drop Python 3.8 support ([a193e78](https://github.com/cjavdev/spotted-py/commit/a193e78635771ec3644b2001979675318ba2f638))
* update SDK settings ([d62d40f](https://github.com/cjavdev/spotted-py/commit/d62d40ff0735d6064bf4c0c23222bb7a5e4540c5))
* update SDK settings ([9cfbf8a](https://github.com/cjavdev/spotted-py/commit/9cfbf8a1247c8e94ac4b6460d59539673c31fe16))
